@@ -1,6 +1,4 @@
-context("Error handling")
-
-context("fn(), fn_()")
+context("Error handling (fn, fn_)")
 
 test_that("error signaled if fn(), fn_() are called without arguments", {
   expect_error(fn(), "Function must be declared")
